@@ -13,7 +13,8 @@
 #include "davjobbase.h"
 #include "davurl.h"
 
-namespace KDAV {
+namespace KDAV
+{
 class DavItemDeleteJobPrivate;
 
 /**
